@@ -28,10 +28,13 @@
 #include "providers/accounts.hpp"
 
 // Global includes
+#include <QtCore/QSettings>
+#include <QtCore/QDir>
 #include <QtGui/QProgressDialog>
 #include <QtGui/QMessageBox>
 #include <QtGui/QMenuBar>
 #include <QtGui/QCloseEvent>
+#include <QtGui/QDesktopServices>
 
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -45,6 +48,7 @@ public:
   MainWindowPrivate()
   : accounts(new Accounts)
   , messageWidget(NULL)
+  , settings(NULL)
   {}
 
   MainWindow* self;
@@ -54,9 +58,13 @@ public:
   StartWidget* startWidget;
   MessageWidget* messageWidget;
 
+  QSettings* settings;
+
   // Functions
   void init();
 
+  void saveMessageTypeSettings();
+
   void login();
   void logout();
 
@@ -76,6 +84,11 @@ void MainWindowPrivate::init()
   accounts->loadPlugins();
   accounts->loadSettings();
 
+  // Hackish solution for remembering the ui settings
+  QDir settingsDir(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
+  settingsDir.cd(".web2sms");
+  settings = new QSettings(settingsDir.absoluteFilePath("web2sms.conf"), QSettings::IniFormat, this);
+
   startWidget = new StartWidget(self);
   startWidget->setAccounts(accounts);
 
@@ -132,6 +145,9 @@ void MainWindowPrivate::onEditAccounts()
 
 void MainWindowPrivate::onAliasClicked(const QString& alias)
 {
+  // Save the message type settings
+  saveMessageTypeSettings();
+
   // Find the provider interface
   ProviderInterface* provider = accounts->providerForAlias(alias);
 
@@ -144,6 +160,41 @@ void MainWindowPrivate::onAliasClicked(const QString& alias)
 
   // Set the provider to the message widget
   messageWidget->setProvider(provider);
+
+  // Restore the previously selected message type
+  {
+    // Create the key and lookup the value
+    QString keyName = QString("messageWidget/%1/currentMessageType").arg(info.providerId().toString());
+    if ( settings->contains(keyName) )
+    {
+      // Get the message type name
+      QString messageTypeName = settings->value(keyName).toString();
+
+      // Create a dummy message type for lookup
+      MessageType dummyMessageType(QString(), messageTypeName, QIcon(), QString(), 0, 0, 0);
+      messageWidget->setCurrentMessageType(dummyMessageType);
+    }
+  }
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+void MainWindowPrivate::saveMessageTypeSettings()
+{
+  // Save the settings of the old provider if possible
+  ProviderInterface* oldProvider = messageWidget->provider();
+  if ( oldProvider )
+  {
+    // Get information about the provider
+    ProviderInfo providerInfo = accounts->providerInfoForProvider(oldProvider);
+
+    // Get the currently selected message type
+    MessageType messageType = messageWidget->currentMessageType();
+
+    // Create the key and set the value
+    QString keyName = QString("messageWidget/%1/currentMessageType").arg(providerInfo.providerId().toString());
+    settings->setValue(keyName, messageType.name());
+  }
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -162,6 +213,7 @@ MainWindow::MainWindow(QWidget *parent /* = 0 */)
 
 MainWindow::~MainWindow()
 {
+  d->saveMessageTypeSettings();
   delete d;
 }
 
