@@ -432,6 +432,30 @@ ProviderInterface* MessageWidget::provider() const
   return d->provider;
 }
 
+//////////////////////////////////////////////////////////////////////////
+
+void MessageWidget::setCurrentMessageType(const MessageType& messageType)
+{
+  // Find the index for the message type
+  QModelIndex index = d->messageTypeModel.indexFromMessageType(messageType);
+
+  // Change the index
+  if ( index.isValid() )
+    d->ui.messageTypePicker->setCurrentIndex(index.row());
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+MessageType MessageWidget::currentMessageType() const
+{
+  // Get the current index of the message type picker
+  int currentIndex = d->ui.messageTypePicker->currentIndex();
+  QModelIndex index = d->messageTypeModel.index(currentIndex);
+
+  // Return the message type
+  return qvariant_cast<MessageType>( index.data(MessageTypeModel::MessageTypeRole) );
+}
+
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
