@@ -44,6 +44,10 @@ public:
   void setProvider(ProviderInterface* provider);
   ProviderInterface* provider() const;
 
+  /// Get/Set the message type
+  void setCurrentMessageType(const MessageType& messageType);
+  MessageType currentMessageType() const;
+
 protected:
   MessageWidgetPrivate* d;
 };
