@@ -24,6 +24,7 @@
 
 // Global includes
 #include <QtCore/QRegExp>
+#include <QtCore/QLocale>
 
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
@@ -40,10 +41,10 @@ bool PROVIDERS_API make_number_international(QString& number)
 
   // Accepted versions (complete international)
   if ( number.startsWith("00") || number.startsWith(QLatin1Char('+')) )
-    return TRUE;
+    return true;
 
   // Country-local
-  if ( number.startsWith("0") )
+  if ( number.startsWith("0") && QLocale::system().country() == QLocale::Germany ) // FIXME: Don't fix only german numbers
   {
     // Insert +49 instead of the first zero. This should be changed into a all-countries
     // compatible version
