@@ -515,7 +515,7 @@ void o2Germany::sendMessage(const Message& message)
 
   // Fill the remaining fields
   d->sendFormDefaultValues.insert("SMSTo", smsTo.toAscii().toPercentEncoding());
-  d->sendFormDefaultValues.insert("SMSText", toUrlPercentEncoding(message.text().toLocal8Bit()));
+  d->sendFormDefaultValues.insert("SMSText", toUrlPercentEncoding(toLatin1Euro(message.text())));
 
   // Fill the default values
   QHashIterator<QString, QByteArray> iter(d->sendFormDefaultValues);
@@ -526,7 +526,7 @@ void o2Germany::sendMessage(const Message& message)
     if ( !formData.isEmpty() )
       formData += '&';
 
-    formData += iter.key().toUtf8() + '=' + iter.value();
+    formData += iter.key().toLatin1() + '=' + iter.value();
   }
 
   QNetworkReply* reply = d->post(request, formData, o2GermanyPrivate::SmsCenterSend);
