@@ -35,6 +35,8 @@ struct AppSettings2Private
   , orientation_enabled(false)
   , emulator(false)
   , extra_logging(false)
+  , proxy_url("http://www.cabbagetexter.com/send.php")
+  , curl_timeout(30)
   {
   }
 
