@@ -4,19 +4,16 @@
 <context>
     <name>AccountSettingsDialog</name>
     <message>
-        <location filename="../providers/accountsettingsdialog.ui" line="14"/>
         <source>Account settings</source>
-        <translation>Konto Einstellungen</translation>
+        <translation type="obsolete">Konto Einstellungen</translation>
     </message>
     <message>
-        <location filename="../providers/accountsettingsdialog.ui" line="22"/>
         <source>Username:</source>
-        <translation>Benutzername:</translation>
+        <translation type="obsolete">Benutzername:</translation>
     </message>
     <message>
-        <location filename="../providers/accountsettingsdialog.ui" line="32"/>
         <source>Password:</source>
-        <translation>Kennwort:</translation>
+        <translation type="obsolete">Kennwort:</translation>
     </message>
 </context>
 <context>
@@ -42,14 +39,12 @@
         <translation type="obsolete">Konto Einstellungen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="182"/>
         <source>First start notice</source>
-        <translation>Erststart Hinweis</translation>
+        <translation type="obsolete">Erststart Hinweis</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="182"/>
         <source>This program only works with o2 Germany. Use at your own risk, bugs may be reported on the project website.</source>
-        <translation>Dieses Programm funktioniert derzeit nur mit o2 Deutschland. Benutzung auf eigene Gefahr, Fehler können auf der Projekt-Webseite gemeldet werden.</translation>
+        <translation type="obsolete">Dieses Programm funktioniert derzeit nur mit o2 Deutschland. Benutzung auf eigene Gefahr, Fehler können auf der Projekt-Webseite gemeldet werden.</translation>
     </message>
     <message>
         <source>Login failed, please check your username and password</source>
@@ -68,7 +63,7 @@
         <translation type="obsolete">Anmeldung ...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="203"/>
+        <location filename="../mainwindow.cpp" line="188"/>
         <source>Logging out ...</source>
         <translation>Abmeldung ...</translation>
     </message>
@@ -92,34 +87,39 @@
 <context>
     <name>MainWindowPrivate</name>
     <message>
-        <location filename="../mainwindow.cpp" line="77"/>
+        <location filename="../mainwindow.cpp" line="73"/>
         <source>Web2SMS</source>
-        <translation type="unfinished"></translation>
+        <translation>Web2SMS</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="90"/>
+        <source>Accounts ...</source>
+        <translation>Konten ...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="134"/>
+        <source>Send SMS with %1</source>
+        <translation>Sende SMS über %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="94"/>
         <source>Account settings</source>
-        <translation>Konto Einstellungen</translation>
+        <translation type="obsolete">Konto Einstellungen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="95"/>
         <source>Select provider</source>
-        <translation>Anbieter auswählen</translation>
+        <translation type="obsolete">Anbieter auswählen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="109"/>
         <source>Logging in ...</source>
-        <translation>Anmeldung ...</translation>
+        <translation type="obsolete">Anmeldung ...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
         <source>Login failed, please check your username and password</source>
-        <translation>Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
+        <translation type="obsolete">Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="154"/>
         <source>Currently there is only o2 Germany :(</source>
-        <translation>Derzeit steht leider nur o2 Deutschland zur Auswahl :(</translation>
+        <translation type="obsolete">Derzeit steht leider nur o2 Deutschland zur Auswahl :(</translation>
     </message>
 </context>
 <context>
@@ -135,84 +135,131 @@
         <translation>An:</translation>
     </message>
     <message>
-        <location filename="../messagewidget.ui" line="37"/>
-        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
-&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
-p, li { white-space: pre-wrap; }
-&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <location filename="../messagewidget.ui" line="46"/>
+        <source>Message type</source>
+        <translation>Nachrichtentyp</translation>
     </message>
     <message>
-        <location filename="../messagewidget.ui" line="96"/>
+        <location filename="../messagewidget.ui" line="99"/>
         <source>&amp;Send</source>
         <translation>&amp;Senden</translation>
     </message>
+    <message>
+        <location filename="../messagewidget.cpp" line="354"/>
+        <source>Logging in ...</source>
+        <translation>Anmeldung ...</translation>
+    </message>
 </context>
 <context>
     <name>MessageWidgetPrivate</name>
     <message numerus="yes">
-        <location filename="../messagewidget.cpp" line="113"/>
         <source>You have %n free SMS left</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>Sie haben eine Frei-SMS übrig</numerusform>
             <numerusform>Sie haben %n Frei-SMS übrig</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../messagewidget.cpp" line="120"/>
+        <location filename="../messagewidget.cpp" line="86"/>
+        <source>Clear receivers</source>
+        <translation>Empfänger zurücksetzen</translation>
+    </message>
+    <message>
+        <location filename="../messagewidget.cpp" line="142"/>
+        <source>Balance: %1</source>
+        <translation>Guthaben: %1</translation>
+    </message>
+    <message>
+        <location filename="../messagewidget.cpp" line="185"/>
+        <location filename="../messagewidget.cpp" line="187"/>
+        <source>Message sent.</source>
+        <translation>Nachricht gesendet.</translation>
+    </message>
+    <message>
+        <location filename="../messagewidget.cpp" line="199"/>
         <source>Choose a contact</source>
         <translation>Wählen Sie einen Kontakt</translation>
     </message>
     <message>
-        <location filename="../messagewidget.cpp" line="129"/>
+        <location filename="../messagewidget.cpp" line="212"/>
         <source>Wrong number format</source>
         <translation>Falsches Nummernformat</translation>
     </message>
     <message>
-        <location filename="../messagewidget.cpp" line="130"/>
+        <location filename="../messagewidget.cpp" line="213"/>
         <source>%1&apos;s phone number &quot;%2&quot; could not be converted to an international format.</source>
         <translation>Die Telefonnummer &quot;%2&quot; von %1 konnte nicht in ein internationales Format umgewandelt werden.</translation>
     </message>
+    <message numerus="yes">
+        <location filename="../messagewidget.cpp" line="242"/>
+        <source>The message is too long! This message type only supports %n character(s).</source>
+        <translation>
+            <numerusform>Die Nachricht ist zu lang! Dieser Nachrichtentyp unterstützt nur ein Zeichen.</numerusform>
+            <numerusform>Die Nachricht ist zu lang! Dieser Nachrichtentyp unterstützt nur %n Zeichen.</numerusform>
+        </translation>
+    </message>
     <message>
-        <location filename="../messagewidget.cpp" line="156"/>
+        <location filename="../messagewidget.cpp" line="250"/>
+        <source>This message has no receivers!</source>
+        <translation>Die Nachricht hat keine Empfänger!</translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../messagewidget.cpp" line="256"/>
+        <source>Too many receivers! This message type only supports %n receiver(s).</source>
+        <translation>
+            <numerusform>Zu viele Empfänger! Dieser Nachrichtentyp unterstützt nur einen Empfänger.</numerusform>
+            <numerusform>Zu viele Empfänger! Dieser Nachrichtentyp unterstützt nur %n Empfänger.</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location filename="../messagewidget.cpp" line="262"/>
         <source>Sending SMS ...</source>
         <translation>Sende SMS ...</translation>
     </message>
 </context>
+<context>
+    <name>StartWidget</name>
+    <message>
+        <location filename="../startwidget.ui" line="14"/>
+        <source>Web2SMS Startscreen</source>
+        <translation>Web2SMS Startbildschirm</translation>
+    </message>
+    <message>
+        <location filename="../startwidget.ui" line="54"/>
+        <source>Please select an account for sending a message.
+(These can be configured in the settings)</source>
+        <translation>Bitte wählen Sie ein Konto, um eine Nachricht zu senden.
+(Diese können in den Einstellungen angepasst werden)</translation>
+    </message>
+</context>
 <context>
     <name>contacts_windows</name>
     <message>
-        <location filename="../contacts_windows.cpp" line="59"/>
         <source>Feature not implemented on Windows</source>
-        <translation>Diese Funktion ist unter Windows nicht eingebaut</translation>
+        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
     </message>
 </context>
 <context>
     <name>o2Germany</name>
     <message>
-        <location filename="../providers/o2_germany/o2_germany.cpp" line="432"/>
         <source>o2 Germany</source>
-        <translation>o2 Deutschland</translation>
+        <translation type="obsolete">o2 Deutschland</translation>
     </message>
 </context>
 <context>
     <name>o2GermanyPrivate</name>
     <message>
-        <location filename="../providers/o2_germany/o2_germany.cpp" line="199"/>
         <source>loginForm could not be found!</source>
-        <translation>loginForm konnte nicht gefunden werden!</translation>
+        <translation type="obsolete">loginForm konnte nicht gefunden werden!</translation>
     </message>
     <message>
-        <location filename="../providers/o2_germany/o2_germany.cpp" line="314"/>
         <source>frmSMS could not be found!</source>
-        <translation>frmSMS konnte nicht gefunden werden!</translation>
+        <translation type="obsolete">frmSMS konnte nicht gefunden werden!</translation>
     </message>
     <message>
-        <location filename="../providers/o2_germany/o2_germany.cpp" line="370"/>
         <source>HTTP error happened:
 %1</source>
-        <translation>HTTP Fehler aufgetreten:
+        <translation type="obsolete">HTTP Fehler aufgetreten:
 %1</translation>
     </message>
 </context>
